@@ -2,52 +2,52 @@
 <context>
     <name>EditShare</name>
     <message>
-        <location filename="../editshare.ui" line="14"/>
+        <location filename="../src/editshare.ui" line="14"/>
         <source>Dialog</source>
         <translation>Διάλογος</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="20"/>
+        <location filename="../src/editshare.ui" line="20"/>
         <source>&amp;Name</source>
         <translation>&amp;Όνομα</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="30"/>
+        <location filename="../src/editshare.ui" line="30"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="37"/>
+        <location filename="../src/editshare.ui" line="37"/>
         <source>&amp;Path</source>
         <translation>&amp;Διαδρομή</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="51"/>
+        <location filename="../src/editshare.ui" line="51"/>
         <source>Yes</source>
         <translation>Ναι</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="56"/>
+        <location filename="../src/editshare.ui" line="56"/>
         <source>No</source>
         <translation>Όχι</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="64"/>
+        <location filename="../src/editshare.ui" line="64"/>
         <source>&amp;Comment</source>
         <translation>&amp;Σχόλιο</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="77"/>
+        <location filename="../src/editshare.ui" line="77"/>
         <source>&amp;Guest OK</source>
         <translation>&amp;Επισκέπτης ΟΚ</translation>
     </message>
     <message>
-        <location filename="../editshare.ui" line="111"/>
+        <location filename="../src/editshare.ui" line="111"/>
         <source>Access rights for valid users</source>
         <translation>Δικαιώματα πρόσβασης για έγκυρους χρήστες</translation>
     </message>
     <message>
-        <location filename="../editshare.cpp" line="52"/>
+        <location filename="../src/editshare.cpp" line="52"/>
         <source>Select directory to share</source>
         <translation>Επιλογή καταλόγου κοινής χρήσης</translation>
     </message>
@@ -55,193 +55,193 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="24"/>
+        <location filename="../src/mainwindow.ui" line="24"/>
         <source>&amp;Shares</source>
         <translation>&amp;Κοινές χρήσεις</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="32"/>
+        <location filename="../src/mainwindow.ui" line="32"/>
         <source>Shares</source>
         <translation>Κοινές χρήσεις</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="41"/>
+        <location filename="../src/mainwindow.ui" line="41"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Δεν βρέθηκαν κοινές χρήσεις του χρήστη samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="50"/>
-        <location filename="../mainwindow.ui" line="157"/>
+        <location filename="../src/mainwindow.ui" line="50"/>
+        <location filename="../src/mainwindow.ui" line="157"/>
         <source>&amp;Remove</source>
         <translation>&amp;Αφαίρεση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="63"/>
-        <location filename="../mainwindow.ui" line="164"/>
+        <location filename="../src/mainwindow.ui" line="63"/>
+        <location filename="../src/mainwindow.ui" line="164"/>
         <source>&amp;Add</source>
         <translation>&amp;Προσθήκη</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="70"/>
+        <location filename="../src/mainwindow.ui" line="70"/>
         <source>&amp;Edit</source>
         <translation>&amp;Επεξεργασία</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="80"/>
+        <location filename="../src/mainwindow.ui" line="80"/>
         <source>Name</source>
         <translation>Όνομα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="85"/>
+        <location filename="../src/mainwindow.ui" line="85"/>
         <source>Path</source>
         <translation>Διαδρομή</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="90"/>
+        <location filename="../src/mainwindow.ui" line="90"/>
         <source>Comment</source>
         <translation>Σχόλιο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="95"/>
+        <location filename="../src/mainwindow.ui" line="95"/>
         <source>Permissions</source>
         <translation>Δικαιώματα πρόσβασης</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="100"/>
+        <location filename="../src/mainwindow.ui" line="100"/>
         <source>Guest OK</source>
         <translation>Επισκέπτης ΟΚ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="142"/>
+        <location filename="../src/mainwindow.ui" line="142"/>
         <source>&amp;Users</source>
         <translation>&amp;Χρήστες</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="150"/>
+        <location filename="../src/mainwindow.ui" line="150"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Δεν βρέθηκαν χρήστες του samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="171"/>
+        <location filename="../src/mainwindow.ui" line="171"/>
         <source>&amp;Password</source>
         <translation>&amp;Κωδικός πρόσβασης</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="194"/>
+        <location filename="../src/mainwindow.ui" line="194"/>
         <source>Users</source>
         <translation>Χρήστες</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="219"/>
-        <location filename="../mainwindow.cpp" line="296"/>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../src/mainwindow.ui" line="219"/>
+        <location filename="../src/mainwindow.cpp" line="305"/>
+        <location filename="../src/mainwindow.cpp" line="346"/>
         <source>E&amp;nable Automatic Samba Startup</source>
         <translation>Ε&amp;νεργοποίηση αυτόματης εκκίνησης Samba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="226"/>
-        <location filename="../mainwindow.cpp" line="292"/>
-        <location filename="../mainwindow.cpp" line="347"/>
+        <location filename="../src/mainwindow.ui" line="226"/>
+        <location filename="../src/mainwindow.cpp" line="301"/>
+        <location filename="../src/mainwindow.cpp" line="356"/>
         <source>Star&amp;t Samba</source>
         <translation>Ε&amp;κκίνηση Samba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="254"/>
+        <location filename="../src/mainwindow.ui" line="254"/>
         <source>Samba autostart service is disabled</source>
         <translation>Η υπηρεσία αυτόματης εκκίνησης Samba είναι απενεργοποιημένη</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="285"/>
-        <location filename="../mainwindow.cpp" line="293"/>
+        <location filename="../src/mainwindow.ui" line="285"/>
+        <location filename="../src/mainwindow.cpp" line="302"/>
         <source>Samba is running</source>
         <translation>Η υπηρεσία Samba βρίσκεται σε λειτουργία</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="324"/>
+        <location filename="../src/mainwindow.ui" line="324"/>
         <source>About this application</source>
         <translation>Περί της εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="327"/>
+        <location filename="../src/mainwindow.ui" line="327"/>
         <source>A&amp;bout...</source>
         <translation>&amp;Περί...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="333"/>
+        <location filename="../src/mainwindow.ui" line="333"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="365"/>
+        <location filename="../src/mainwindow.ui" line="365"/>
         <source>Display help </source>
         <translation>Εμφάνιση βοήθειας </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="368"/>
+        <location filename="../src/mainwindow.ui" line="368"/>
         <source>&amp;Help</source>
         <translation>&amp;Βοήθεια</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="374"/>
+        <location filename="../src/mainwindow.ui" line="374"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="409"/>
+        <location filename="../src/mainwindow.ui" line="409"/>
         <source>Quit application</source>
         <translation>Κλείσιμο εφαρμογής</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="412"/>
+        <location filename="../src/mainwindow.ui" line="412"/>
         <source>&amp;Close</source>
         <translation>&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="418"/>
+        <location filename="../src/mainwindow.ui" line="418"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="104"/>
-        <location filename="../mainwindow.cpp" line="109"/>
-        <location filename="../mainwindow.cpp" line="136"/>
-        <location filename="../mainwindow.cpp" line="147"/>
-        <location filename="../mainwindow.cpp" line="203"/>
-        <location filename="../mainwindow.cpp" line="276"/>
-        <location filename="../mainwindow.cpp" line="287"/>
-        <location filename="../mainwindow.cpp" line="386"/>
-        <location filename="../mainwindow.cpp" line="418"/>
-        <location filename="../mainwindow.cpp" line="422"/>
-        <location filename="../mainwindow.cpp" line="428"/>
-        <location filename="../mainwindow.cpp" line="433"/>
-        <location filename="../mainwindow.cpp" line="471"/>
-        <location filename="../mainwindow.cpp" line="476"/>
-        <location filename="../mainwindow.cpp" line="482"/>
-        <location filename="../mainwindow.cpp" line="503"/>
-        <location filename="../mainwindow.cpp" line="520"/>
-        <location filename="../mainwindow.cpp" line="539"/>
-        <location filename="../mainwindow.cpp" line="554"/>
-        <location filename="../mainwindow.cpp" line="569"/>
+        <location filename="../src/mainwindow.cpp" line="104"/>
+        <location filename="../src/mainwindow.cpp" line="109"/>
+        <location filename="../src/mainwindow.cpp" line="136"/>
+        <location filename="../src/mainwindow.cpp" line="147"/>
+        <location filename="../src/mainwindow.cpp" line="203"/>
+        <location filename="../src/mainwindow.cpp" line="285"/>
+        <location filename="../src/mainwindow.cpp" line="296"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
+        <location filename="../src/mainwindow.cpp" line="427"/>
+        <location filename="../src/mainwindow.cpp" line="431"/>
+        <location filename="../src/mainwindow.cpp" line="437"/>
+        <location filename="../src/mainwindow.cpp" line="444"/>
+        <location filename="../src/mainwindow.cpp" line="482"/>
+        <location filename="../src/mainwindow.cpp" line="487"/>
+        <location filename="../src/mainwindow.cpp" line="495"/>
+        <location filename="../src/mainwindow.cpp" line="516"/>
+        <location filename="../src/mainwindow.cpp" line="533"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
+        <location filename="../src/mainwindow.cpp" line="567"/>
+        <location filename="../src/mainwindow.cpp" line="582"/>
         <source>Error</source>
         <translation>Σφάλμα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="104"/>
+        <location filename="../src/mainwindow.cpp" line="104"/>
         <source>Error, could not add share. Empty share name</source>
         <translation>Σφάλμα, δεν κατέστη δυνατή η προσθήκη κοινής χρήσης. Κενό όνομα</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="101"/>
+        <location filename="../src/mainwindow.cpp" line="101"/>
         <source>Yes</source>
         <translation>Ναι</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="109"/>
+        <location filename="../src/mainwindow.cpp" line="109"/>
         <source>Path: %1 does not exist.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../src/mainwindow.cpp" line="137"/>
         <source>Could not add share. Error message:
 
 %1</source>
@@ -250,211 +250,211 @@
 %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="147"/>
+        <location filename="../src/mainwindow.cpp" line="147"/>
         <source>Error listing users</source>
         <translation>Σφάλμα καταχώρισης χρηστών</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="186"/>
+        <location filename="../src/mainwindow.cpp" line="186"/>
         <source>&amp;Deny</source>
         <translation>Ά&amp;ρνηση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="187"/>
+        <location filename="../src/mainwindow.cpp" line="187"/>
         <source>&amp;Read Only</source>
         <translation>&amp;Μόνο για ανάγνωση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="188"/>
+        <location filename="../src/mainwindow.cpp" line="188"/>
         <source>&amp;Full Access</source>
         <translation>&amp;Πλήρης πρόσβαση</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="203"/>
+        <location filename="../src/mainwindow.cpp" line="203"/>
         <source>Error listing shares</source>
         <translation>Σφάλμα καταχώρισης κοινής χρήσης</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="277"/>
+        <location filename="../src/mainwindow.cpp" line="286"/>
         <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
         <translation>Ο χρήστης σας δεν ανήκει στην ομάδα &apos;sambasshare&apos; εάν εγκαταστήσατε τώρα την εφαρμογή, ίσως χρειαστεί να κάνετε πρώτα επανεκκίνηση του συστήματος.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../src/mainwindow.cpp" line="296"/>
         <source>Samba is not installed</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="292"/>
+        <location filename="../src/mainwindow.cpp" line="301"/>
         <source>Sto&amp;p Samba</source>
         <translation>&amp;Διακοπή του Samba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="293"/>
+        <location filename="../src/mainwindow.cpp" line="302"/>
         <source>Samba is not running</source>
         <translation>Το Samba δεν λειτουργεί</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="294"/>
+        <location filename="../src/mainwindow.cpp" line="303"/>
         <source>Samba autostart is enabled</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="294"/>
+        <location filename="../src/mainwindow.cpp" line="303"/>
         <source>Samba autostart is disabled</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="295"/>
+        <location filename="../src/mainwindow.cpp" line="304"/>
         <source>&amp;Disable Automatic Samba Startup</source>
         <translation>&amp;Απενεργοποίηση αυτόματης εκκίνησης του Samba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../src/mainwindow.cpp" line="371"/>
         <source>About %1</source>
         <translation>Περί του %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../src/mainwindow.cpp" line="371"/>
         <source>MX Samba Config</source>
         <translation>MX Ρυθμίσεις Samba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="363"/>
+        <location filename="../src/mainwindow.cpp" line="372"/>
         <source>Version: </source>
         <translation>Έκδοση: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="365"/>
+        <location filename="../src/mainwindow.cpp" line="374"/>
         <source>Program for configuring Samba shares and users.</source>
         <translation>Πρόγραμμα για τη ρύθμιση κοινών χρήσεων και χρηστών του Samba.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="367"/>
+        <location filename="../src/mainwindow.cpp" line="376"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="368"/>
+        <location filename="../src/mainwindow.cpp" line="377"/>
         <source>%1 License</source>
         <translation>Άδεια %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../src/mainwindow.cpp" line="384"/>
         <source>%1 Help</source>
         <translation>Βοήθεια %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="386"/>
+        <location filename="../src/mainwindow.cpp" line="395"/>
         <source>Cannot delete user: </source>
         <translation>Δεν κατέστη δυνατή η διαγραφή του χρήστη: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="395"/>
+        <location filename="../src/mainwindow.cpp" line="404"/>
         <source>Enter the username and password:</source>
         <translation>Εισαγωγή ονόματος και κωδικού πρόσβασης χρήστη:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="402"/>
+        <location filename="../src/mainwindow.cpp" line="411"/>
         <source>Username:</source>
         <translation>Όνομα:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <location filename="../mainwindow.cpp" line="457"/>
+        <location filename="../src/mainwindow.cpp" line="412"/>
+        <location filename="../src/mainwindow.cpp" line="468"/>
         <source>Password:</source>
         <translation>Κωδικός πρόσβασης:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="404"/>
-        <location filename="../mainwindow.cpp" line="458"/>
+        <location filename="../src/mainwindow.cpp" line="413"/>
+        <location filename="../src/mainwindow.cpp" line="469"/>
         <source>Confirm password:</source>
         <translation>Επιβεβαίωση κωδικού:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="418"/>
+        <location filename="../src/mainwindow.cpp" line="427"/>
         <source>Empty username, please enter a name.</source>
         <translation>Κενό όνομα χρήστη, παρακαλώ πληκτρολογείστε ένα όνομα.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="423"/>
+        <location filename="../src/mainwindow.cpp" line="432"/>
         <source>Matching linux user not found on system, make sure you enter a valid username.</source>
         <translation>Δεν βρέθηκε αντιστοίχιση με χρήστη του συστήματος, βεβαιωθείτε ότι έχετε εισαγάγει ένα έγκυρο όνομα χρήστη.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="428"/>
-        <location filename="../mainwindow.cpp" line="476"/>
+        <location filename="../src/mainwindow.cpp" line="437"/>
+        <location filename="../src/mainwindow.cpp" line="487"/>
         <source>Passwords don&apos;t match, please enter again.</source>
         <translation>Οι κωδικοί πρόσβασης δεν ταιριάζουν, παρακαλώ δοκιμάστε πάλι.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="433"/>
+        <location filename="../src/mainwindow.cpp" line="444"/>
         <source>Could not add user.</source>
         <translation>Δεν κατέστη δυνατή η προσθήκη χρήστη.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
-        <location filename="../mainwindow.cpp" line="492"/>
-        <location filename="../mainwindow.cpp" line="498"/>
-        <location filename="../mainwindow.cpp" line="515"/>
+        <location filename="../src/mainwindow.cpp" line="455"/>
+        <location filename="../src/mainwindow.cpp" line="505"/>
+        <location filename="../src/mainwindow.cpp" line="511"/>
+        <location filename="../src/mainwindow.cpp" line="528"/>
         <source>Warning</source>
         <translation>Προσοχή</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../src/mainwindow.cpp" line="455"/>
         <source>No user selected.</source>
         <translation>Δεν επιλέξατε κανέναν Χρήστη.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="451"/>
+        <location filename="../src/mainwindow.cpp" line="462"/>
         <source>Change the password for &apos;%1&apos;</source>
         <translation>Αλλαγή κωδικού πρόσβασης για τον &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="471"/>
+        <location filename="../src/mainwindow.cpp" line="482"/>
         <source>Password fields cannot be empty.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="482"/>
+        <location filename="../src/mainwindow.cpp" line="495"/>
         <source>Could not change password.</source>
         <translation>Δεν κατέστη δυνατή η αλλαγή του κωδικού πρόσβασης.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="492"/>
-        <location filename="../mainwindow.cpp" line="515"/>
+        <location filename="../src/mainwindow.cpp" line="505"/>
+        <location filename="../src/mainwindow.cpp" line="528"/>
         <source>No share selected.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="498"/>
+        <location filename="../src/mainwindow.cpp" line="511"/>
         <source>Selected share is empty.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="503"/>
+        <location filename="../src/mainwindow.cpp" line="516"/>
         <source>Cannot delete share: </source>
         <translation>Δεν κατέστη δυνατή η διαγραφή της κοινής χρήσης: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="508"/>
+        <location filename="../src/mainwindow.cpp" line="521"/>
         <source>Success</source>
         <translation>Επιτυχία</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="508"/>
+        <location filename="../src/mainwindow.cpp" line="521"/>
         <source>Share deleted successfully: </source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="521"/>
-        <location filename="../mainwindow.cpp" line="570"/>
+        <location filename="../src/mainwindow.cpp" line="534"/>
+        <location filename="../src/mainwindow.cpp" line="583"/>
         <source>Samba service is not running. Please start Samba before adding or editing shares</source>
         <translation>Η υπηρεσία Samba δεν λειτουργεί. Ξεκινήστε το Samba πριν προσθέσετε ή επεξεργαστείτε κοινές χρήσεις</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="539"/>
-        <location filename="../mainwindow.cpp" line="554"/>
+        <location filename="../src/mainwindow.cpp" line="552"/>
+        <location filename="../src/mainwindow.cpp" line="567"/>
         <source>Error processing permissions: </source>
         <translation type="unfinished"/>
     </message>
@@ -462,28 +462,28 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="42"/>
+        <location filename="../src/about.cpp" line="45"/>
         <source>License</source>
         <translation>Άδεια</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="43"/>
-        <location filename="../about.cpp" line="52"/>
+        <location filename="../src/about.cpp" line="46"/>
+        <location filename="../src/about.cpp" line="55"/>
         <source>Changelog</source>
         <translation>Αρχείο αλλαγών</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="44"/>
+        <location filename="../src/about.cpp" line="47"/>
         <source>Cancel</source>
         <translation>Άκυρο</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="64"/>
+        <location filename="../src/about.cpp" line="67"/>
         <source>&amp;Close</source>
         <translation>&amp;Κλείσιμο</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="64"/>
+        <location filename="../src/main.cpp" line="71"/>
         <source>You must run this program as normal user.</source>
         <translation>Πρέπει να τρέξετε αυτή την εφαρμογή ως απλός χρήστης.</translation>
     </message>
